//LabPlot : FileInfoDialog.h

#ifndef FILEINFODIALOG_H
#define FILEINFODIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include "Worksheet.h"
#include "Dialog.h"

#include "FilterNETCDF.h"
#include "FilterCDF.h"

class FileInfoDialog: public Dialog
{
	Q_OBJECT
public:
	FileInfoDialog(MainWin *mw, const char *name, QString filename);
private slots:
	void updateVarListBox();
private:
	QListBox *varlb, *selvarlb;	// listbox of all variables / for selected variable
	QLabel *varlabel;			// label of selected variable
	FilterNETCDF ncf;			// filter for netcdf files
	FilterCDF cdf;				// filter for cdf files
};

#endif //FILEINFODIALOG_H
